@@ -2,7 +2,4 @@ __author__ = 'pooyadav'
 
 from pythonzestclient.pyZestClient import *
 from pythonzestclient.pyZestUtil import *
-from pythonzestclient.exception.pyZestException import *
-
-
-
+from pythonzestclient.exception import *
